pub struct OfflineEvidence {
pub validator: ValidatorId,
pub missed_commits: u64,
pub total_commits: u64,
pub evidence_height: Height,
}Expand description
Offline evidence reported to the application at epoch boundaries.
Fields
validator: ValidatorIdmissed_commits: u64total_commits: u64evidence_height: HeightThe height at which this evidence was produced (last committed block).