Pacemaker

Struct Pacemaker 

pub struct Pacemaker {
    pub view_deadline: Instant,
    /* private fields */
}
Full pacemaker with exponential backoff and TC relay

Fields

view_deadline: Instant

Implementations

Source

impl Pacemaker

pub fn new() -> Self

pub fn reset_timer(&mut self)

Reset timer with current backoff-adjusted timeout

pub fn reset_on_progress(&mut self)

Reset timer after successful view completion (resets backoff)

pub fn on_timeout(&mut self)

Increase timeout with exponential backoff after a timeout event

pub fn sleep_until_deadline(&self) -> Sleep

pub fn current_timeout(&self) -> Duration

pub fn consecutive_timeouts(&self) -> u32

pub fn build_wish( &self, current_view: ViewNumber, validator_id: ValidatorId, highest_qc: Option<QuorumCertificate>, signer: &dyn Signer, ) -> ConsensusMessage

Build the Wish message for timeout

pub fn add_wish( &mut self, vs: &ValidatorSet, target_view: ViewNumber, validator: ValidatorId, highest_qc: Option<QuorumCertificate>, signature: Signature, ) -> Option<TimeoutCertificate>

Add a wish and check if we have 2f+1 to form a TC

pub fn should_relay_tc(&mut self, tc: &TimeoutCertificate) -> bool

Check if we should relay a received TC (returns true if not yet relayed)

pub fn clear_view(&mut self, view: ViewNumber)

pub fn prune_before(&mut self, min_view: ViewNumber)

Prune old relay tracking data